#
# SelectionDialog
#

xmPushButton .btn managed
xmSelectionDialog .btn.bbd managed \
    -selectionLabelString "Enter or select colour" \
    -listItems "red green blue" \
    -listItemCount 3 \
    -listLabelString "Colours:"
